<?php
/*
WPListCal Admin functions

Permission is hereby granted, free of charge, to any person or organization
obtaining a copy of the software and accompanying documentation covered by
this license (the "Software") to use, reproduce, display, distribute,
execute, and transmit the Software, and to prepare derivative works of the
Software, and to permit third-parties to whom the Software is furnished to
do so, all subject to the following:

The copyright notices in the Software and this entire statement, including
the above license grant and author attributions, this restriction, and the
following disclaimer, must be included in all copies of the Software, in
whole or in part, and all derivative works of the Software, unless such
copies or derivative works are solely in the form of machine-executable 
object code generated by a source language processor.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
*/

if(wplc_is_wplc_page()) {
	add_action( 'admin_head', 'wplc_editor_init' );
	function wplc_editor_init() {
		wp_admin_css('thickbox');
		wp_print_scripts('editor');
		add_thickbox();
		wp_print_scripts('media-upload');
		wp_print_scripts('jquery');
		wp_print_scripts('jquery-ui-core');
		wp_print_scripts('jquery-ui-tabs');
		if(function_exists('wp_tiny_mce')) wp_tiny_mce();
	}
}

function wplc_show_event_form($event=array(), $message=null, $export=false) {
	wplc_setup();
	global $wplc_domain;
	
	wplc_upgrade_if_needed();
	
	$editing = count($event) != 0;
	
	$use_24hr_time = get_option("wplc_use_24hr_time");
	if(!is_bool($use_24hr_time)) {
		$use_24hr_time = $use_24hr_time == "true";
	}

	// Prep event times
	$d = $event['event_start_time'];
	if(empty($d))
		$d = wplc_time();
	$date['event_start_month'] = date('n', $d);
	$date['event_start_day'] = date('j', $d);
	$date['event_start_year'] = date('Y', $d);
	if($use_24hr_time)
		$date['event_start_hour'] = date('G', $d);
	else
		$date['event_start_hour'] = date('g', $d);
	$date['event_start_minute'] = date('i', $d);
	if(!$use_24hr_time)
		$date['event_start_ampm'] = date('A', $d);
	
	$d = $event['event_end_time'];
	if(empty($d))
		$d = wplc_time() + 3600;
	$date['event_end_month'] = date('n', $d);
	$date['event_end_day'] = date('j', $d);
	$date['event_end_year'] = date('Y', $d);
	if($use_24hr_time)
		$date['event_end_hour'] = date('G', $d);
	else
		$date['event_end_hour'] = date('g', $d);
	$date['event_end_minute'] = date('i', $d);
	if(!$use_24hr_time)
		$date['event_end_ampm'] = date('A', $d);
		
	get_currentuserinfo();
	global $user_ID;
	
	if($editing) {
		$time_format = "M j, Y @ ";
		
		if($use_24hr_time) {
			$time_format .= "G:i";
		}
		else {
			$time_format .= "g:ia";
		}
		
		if($event['event_create_time'] == '0') {
			$create_time = __("N/A", $wplc_domain);
		}
		else {
			$create_time = date($time_format, $event['event_create_time']);
		}
		if($event['event_modified_time'] == '0') {
			$modified_time = __("N/A", $wplc_domain);
		}
		else {
			$modified_time = date($time_format, $event['event_modified_time']);
		}
		
		if($event['event_author'] == null) {
			$author = __("N/A", $wplc_domain);
		}
		else {
			$author = $event['event_author'];
		}
	}
	
	if(!is_null($message)) {
	?>
		<div id="message" class="updated fade">
			<p>
				<?php echo $message; ?>
			</p>
		</div>
	<?php
	}
	?>
	<div class="wrap">
		<h2><?php echo $editing ? __("Edit Event", $wplc_domain) : __("Add New Event", $wplc_domain); ?></h2>
		<form name="event" id="event" method="post" action="<?php echo $_SERVER['REQUEST_URI']; ?>">
			<input type="hidden" id="user-id" name="user_ID" value="<?php echo (int) $user_ID ?>" />
			<div id="poststuff">
				<div style="position:relative;" class="has-right-sidebar">
					<div class="inner-sidebar">
						<div class="postbox" id="submitdiv">
							<h3 class="wplc_plaincursor">
								<span><?php _e('Publish', $wplc_domain); ?></span>
							</h3>
							<div class="inside">
								<div class="submitbox">
									<div id="minor-publishing">
										<?php if($editing) { ?>
											<div class="misc-pub-section">
												<label class="wplc_baseline"><?php _e("Author:", $wplc_domain); ?></label>
												<b><?php echo $author; ?></b>
											</div>
											<div class="misc-pub-section">
												<label class="wplc_baseline"><?php _e("Published on:", $wplc_domain); ?></label>
												<b><?php echo $create_time; ?></b>
											</div>
											<?php if($create_time != $modified_time) { ?>
												<div class="misc-pub-section">
													<label class="wplc_baseline"><?php _e("Modified on:", $wplc_domain); ?></label>
													<b><?php echo $modified_time; ?></b>
												</div>
											<?php } ?>
											<div class="misc-pub-section misc-pub-section-last">
												<?php
												if($editing) {
													$dellink = "admin.php?page=wplc-edit&op=delete&id=".$event['id'];
													$dellink = (function_exists('wp_nonce_url')) ? wp_nonce_url($dellink, 'wplc-delete-event') : $dellink;
													echo "<a class='submitdelete' href='".$dellink."' onclick=\"if(confirm('".__('You are about to delete this event \\\''.stripslashes($event['event_name']).'\\\'\n \\\'Cancel\\\' to stop, \\\'OK\\\' to delete.', $wplc_domain)."')) { return true; } return false;\">".__("Delete Event", $wplc_domain)."</a>";
													?> | 
													<a class='wplc_link' href="admin.php?page=wplc-edit&amp;op=editexport&amp;id=<?php echo $event['id']; ?>"><?php _e("Export", $wplc_domain); ?></a>
													<?php
												}
												?>
											</div>
										<?php }
										else {
											echo "&nbsp;";
										} ?>
									</div>
									<div id="major-publishing-actions">
										<div id="delete-action">
											<input type="submit" name="saveandnew" id="save-new-post" value="<?php _e('Save and new', $wplc_domain); ?>" tabindex="16" class="button" />
										</div>
										<div id="publishing-action">
											<input type="submit" name="save" id="save-post" value="<?php _e('Save', $wplc_domain); ?>" tabindex="17" class="button-primary" />
										</div>
										<div class="clear"></div>
									</div>
								</div>
							</div>
						</div>
					</div>
				<div id="post-body" class="has-sidebar">
					<div id="post-body-content" class="has-sidebar-content">
						<input type="hidden" name="action" value="submitted" />
						<?php
						if($editing) {
						?>
							<input type="hidden" name="id" value="<?php echo $event['id']; ?>" />
						<?php
						}
						?>
						<div id="titlediv-noformat" class="postbox">
							<h3 class="wplc_plaincursor"><?php _e('Title', $wplc_domain); ?></h3>
							<div id="titlewrap-noformat" class="inside">
								<label class="hidden" for="title-noformat">Title</label>
								<input type="text" name="event_name" size="30" tabindex="1" value="<?php echo stripslashes(stripslashes($event['event_name'])); ?>" id="title-noformat" />
							</div>
						</div>
						
						<div id="locdiv" class="postbox">
							<h3 class="wplc_plaincursor"><?php _e('Location', $wplc_domain); ?></h3>
							<div id="locwrap" class="inside">
								<label class="hidden" for="location">Location</label>
								<input type="text" name="event_loc" size="30" tabindex="2" value="<?php echo stripslashes(stripslashes($event['event_loc'])); ?>" id="location" />
							</div>
						</div>
					
						<div id="linkdiv" class="postbox">
							<h3 class="wplc_plaincursor"><?php _e('Link', $wplc_domain); ?></h3>
							<div id="linkwrap" class="inside">
								<label class="hidden" for="link">Link</label>
								<input type="text" name="event_link" size="30" tabindex="2" value="<?php echo stripslashes(stripslashes($event['event_link'])); ?>" id="link" />
							</div>
						</div>

						<div id="startdiv" class="postbox">
							<h3 class="wplc_plaincursor"><?php _e('Date/Time', $wplc_domain); ?></h3>
							<div id="startwrap" class="inside">
								<div style="clear:both;float:none;">
									<label class="wplc_date_label">Start:</label>
									<div class="wplc_date_body">
										<?php
											$s[$date['event_start_month']] = " selected='selected'";
										?>
										<select name="start-month" id="start-month" onchange="wplc_matchValue('start-month', 'end-month', true);" tabindex="3">
											<option value="1"<?php echo $s['1']; ?>><?php _e('Jan', $wplc_domain); ?></option>
											<option value="2"<?php echo $s['2']; ?>><?php _e('Feb', $wplc_domain); ?></option>
											<option value="3"<?php echo $s['3']; ?>><?php _e('Mar', $wplc_domain); ?></option>
											<option value="4"<?php echo $s['4']; ?>><?php _e('Apr', $wplc_domain); ?></option>
											<option value="5"<?php echo $s['5']; ?>><?php _e('May', $wplc_domain); ?></option>
											<option value="6"<?php echo $s['6']; ?>><?php _e('Jun', $wplc_domain); ?></option>
											<option value="7"<?php echo $s['7']; ?>><?php _e('Jul', $wplc_domain); ?></option>
											<option value="8"<?php echo $s['8']; ?>><?php _e('Aug', $wplc_domain); ?></option>
											<option value="9"<?php echo $s['9']; ?>><?php _e('Sep', $wplc_domain); ?></option>
											<option value="10"<?php echo $s['10']; ?>><?php _e('Oct', $wplc_domain); ?></option>
											<option value="11"<?php echo $s['11']; ?>><?php _e('Nov', $wplc_domain); ?></option>
											<option value="12"<?php echo $s['12']; ?>><?php _e('Dec', $wplc_domain); ?></option>
										</select>
										<input type="text" name="start-day" id="start-day" size="2" maxlength="2" value="<?php echo $date['event_start_day']; ?>" tabindex="4" onblur="wplc_matchValue('start-day', 'end-day', false);" />
										<input type="text" name="start-year" id="start-year" size="4" maxlength="4" value="<?php echo $date['event_start_year']; ?>" tabindex="5" onblur="wplc_matchValue('start-year', 'end-year', false);" />
										<span id="start-time-cont"<?php echo $event['event_allday']==1 ? " style='visibility:hidden;'" : ""; ?>>
											@ <input type="text" name="start-hour" id="start-hour" size="2" maxlength="2" value="<?php echo $date['event_start_hour']; ?>" tabindex="6" onblur="wplc_matchValue('start-hour', 'end-hour', false);" />
											: <input type="text" name="start-minute" id="start-minute" size="2" maxlength="2" value="<?php echo $date['event_start_minute']; ?>" tabindex="7" onblur="wplc_matchValue('start-minute', 'end-minute', false);" />
											<?php
												if(!$use_24hr_time) {
													$s[$date['event_start_ampm']] = " selected='selected'";
											?>
											<select name="start-ampm" id="start-ampm" tabindex="8" onchange="wplc_matchValue('start-ampm', 'end-ampm', true);">
												<option value="AM"<?php echo $s['AM']; ?>>AM</option>
												<option value="PM"<?php echo $s['PM']; ?>>PM</option>
											</select>
										</span>
										<?php
											}
										?>
									</div>
								</div>
								<div style="padding-top:15px;clear:both;float:none;">
									<label class="wplc_date_label">End:</label>
									<div class="wplc_date_body">
										<?php
											unset($s);
											$s[$date['event_end_month']] = " selected='selected'";
										?>
										<select name="end-month" tabindex="9" id="end-month" onfocus="editable = true;" onblur="editable = false;" onchange="fieldsDirty = editable ? true : fieldsDirty;">
											<option value="1"<?php echo $s['1']; ?>><?php _e('Jan', $wplc_domain); ?></option>
											<option value="2"<?php echo $s['2']; ?>><?php _e('Feb', $wplc_domain); ?></option>
											<option value="3"<?php echo $s['3']; ?>><?php _e('Mar', $wplc_domain); ?></option>
											<option value="4"<?php echo $s['4']; ?>><?php _e('Apr', $wplc_domain); ?></option>
											<option value="5"<?php echo $s['5']; ?>><?php _e('May', $wplc_domain); ?></option>
											<option value="6"<?php echo $s['6']; ?>><?php _e('Jun', $wplc_domain); ?></option>
											<option value="7"<?php echo $s['7']; ?>><?php _e('Jul', $wplc_domain); ?></option>
											<option value="8"<?php echo $s['8']; ?>><?php _e('Aug', $wplc_domain); ?></option>
											<option value="9"<?php echo $s['9']; ?>><?php _e('Sep', $wplc_domain); ?></option>
											<option value="10"<?php echo $s['10']; ?>><?php _e('Oct', $wplc_domain); ?></option>
											<option value="11"<?php echo $s['11']; ?>><?php _e('Nov', $wplc_domain); ?></option>
											<option value="12"<?php echo $s['12']; ?>><?php _e('Dec', $wplc_domain); ?></option>
										</select>
										<input type="text" name="end-day" id="end-day" size="2" maxlength="2" value="<?php echo $date['event_end_day']; ?>" tabindex="10" onfocus="editable = true;" onblur="editable = false;" onchange="fieldsDirty = editable ? true : fieldsDirty;" />
										<input type="text" name="end-year" id="end-year" size="4" maxlength="4" value="<?php echo $date['event_end_year']; ?>" tabindex="11" onfocus="editable = true;" onblur="editable = false;" onchange="fieldsDirty = editable ? true : fieldsDirty;" />
										<span id="end-time-cont"<?php echo $event['event_allday']==1 ? " style='visibility:hidden;'" : ""; ?>>
											@ <input type="text" name="end-hour" id="end-hour" size="2" maxlength="2" value="<?php echo $date['event_end_hour']; ?>" tabindex="12" onfocus="editable = true;" onblur="editable = false;" onchange="fieldsDirty = editable ? true : fieldsDirty;" />
											: <input type="text" name="end-minute" id="end-minute" size="2" maxlength="2" value="<?php echo $date['event_end_minute']; ?>" tabindex="13" onfocus="editable = true;" onblur="editable = false;" onchange="fieldsDirty = editable ? true : fieldsDirty;" />
											<?php
												if(!$use_24hr_time) {
													$s[$date['event_end_ampm']] = " selected='selected'";
											?>
											<select name="end-ampm" id="end-ampm" tabindex="14" onfocus="editable = true;" onblur="editable = false;" onchange="fieldsDirty = editable ? true : fieldsDirty;">
												<option value="AM"<?php echo $s['AM']; ?>>AM</option>
												<option value="PM"<?php echo $s['PM']; ?>>PM</option>
											</select>
										</span>
										<?php
											}
										?>
									</div>
								</div>
								<div style="clear:both;">
									&nbsp;
								</div>
							</div>
						</div>
	
						<div id="<?php echo user_can_richedit() ? 'postdivrich' : 'postdiv'; ?>" class="postarea">
							<?php
							the_editor(stripslashes(stripslashes($event['event_desc'])) /*content*/, "content" /*id*/, "end-ampm" /*prev_id*/, true /*media_buttons*/, 15 /*tab_index*/);
							?>
						</div>
					</div>
				</div>
			</div>
		</form>
	</div>
	<script type="text/javascript" charset="utf-8">
	//<![CDATA[
	try{document.getElementById("title-noformat").focus();} catch(e) {}
	//]]>
	</script>
	<?php
	
	if($export) {
		wplc_export_events($event['id']);
	}
}

function wplc_process_event($postvars) {
	wplc_setup();
	global $wplc_domain, $wpdb, $current_user;
	get_currentuserinfo();

	$gobacktoeditform = !empty($postvars['save']);

	$name = addslashes($postvars['event_name']);
	$location = addslashes($postvars['event_loc']);
	$link = addslashes($postvars['event_link']);
	$description = addslashes($postvars['content']);
	
	$tbl_name = $wpdb->escape(get_option("wplc_tbl_name"));
	
	$allday = $postvars['event_allday'] == 1;
	if($allday) {
		$start_time = "0:00";
		$end_time = "23:59";
	}
	else {
		$start_time = addslashes($postvars['start-hour']).":".
		addslashes($postvars['start-minute']).
		$postvars['start-ampm'];
		
		$end_time = addslashes($postvars['end-hour']).":".
		addslashes($postvars['end-minute']).
		$postvars['end-ampm'];
	}

	// Get timestamps from date/time info
	$startstr = addslashes($postvars['start-year'])."-".
				$postvars['start-month']."-".
				addslashes($postvars['start-day'])." ".
				$start_time;
	$endstr = addslashes($postvars['end-year'])."-".
				$postvars['end-month']."-".
				addslashes($postvars['end-day'])." ".
				$end_time;
	$start = strtotime($startstr);
	$end = strtotime($endstr);
	
	$author = $current_user->ID;
	$create_mod_time = wplc_time();

	// Validation & Error Handling
	// If name is empty, just refresh the post page
	if(empty($name)) {
		wplc_show_event_form();
		return;
	}
	// If start time is invalid, use NOW
	if($start === -1 || $start === false)
		$start = wplc_time();
	// If end time is invalid, use start
	if($end === -1 || $end === false)
		$end = $start;
	// If end is before start time, set end to start
	if($end < $start)
		$end = $start;
	
	// Add data to db
	if(empty($postvars['id'])) {
		$insert = "INSERT INTO ".$tbl_name.
				  " (event_name, event_link, event_loc, event_desc, event_start_time, event_end_time, event_allday, event_author, event_create_time, event_modified_time) ".
				  "VALUES('".$wpdb->escape($name)."',
						  '".$wpdb->escape($link)."',
						  '".$wpdb->escape($location)."',
						  '".$wpdb->escape($description)."',
						  '".$wpdb->escape($start)."',
						  '".$wpdb->escape($end)."',
						  ".$wpdb->escape($allday ? '1' : '0').",
						  '".$wpdb->escape($author)."',
						  '".$wpdb->escape($create_mod_time)."',
						  '".$wpdb->escape($create_mod_time)."');";
		$results = $wpdb->query($insert);
	}
	else {
		$update = "UPDATE ".$tbl_name.
			  	  " SET event_name='".$wpdb->escape($name)."',".
				  "event_link='".$wpdb->escape($link)."',".
				  "event_loc='".$wpdb->escape($location)."',".
				  "event_desc='".$wpdb->escape($description)."',".
				  "event_start_time='".$wpdb->escape($start)."',".
				  "event_end_time='".$wpdb->escape($end)."',".
				  "event_allday=".$wpdb->escape($allday ? '1' : '0').",".
				  "event_modified_time='".$wpdb->escape($create_mod_time)."' ".
				  "WHERE id=".$wpdb->escape($postvars['id']);
		$results = $wpdb->query($update);
	}
	
	$msg = empty($postvars['id']) ? __("Event Added", $wplc_domain) : __("Event Updated", $wplc_domain);
	
	if($gobacktoeditform) {
		$id = empty($postvars['id']) ? $wpdb->insert_id : $postvars['id'];
		$sql = "SELECT e.*, u.display_name as event_author FROM ".$wpdb->escape(get_option("wplc_tbl_name"))." e LEFT JOIN ".$wpdb->users." u ON e.event_author = u.ID WHERE e.id=".$wpdb->escape($id);
		$event = $wpdb->get_results($sql, ARRAY_A);

		// Show edit form
		wplc_show_event_form($event[0], $msg);
	}
	else {
		wplc_show_event_form(array(), $msg);
	}
}

function wplc_show_admin_write_page() {
	wplc_setup();
	global $wplc_domain;

	$action = $_POST['action'];
	if($action == "submitted") {
		wplc_process_event($_POST);
	}
	else
		wplc_show_event_form();
}

add_action('admin_menu', 'wplc_add_admin_pages');
function wplc_add_admin_pages() {
	wplc_setup();
	global $wplc_domain, $wplc_dir, $wplc_plugin;
	
	add_object_page(__("Events"), __("Events"), 2, $wplc_plugin, "wplc_show_admin_write_page", $wplc_dir."/icon.gif");
	
	add_submenu_page($wplc_plugin, __("Add New Event", $wplc_domain), __("Add New", $wplc_domain), "edit_posts", $wplc_plugin, "wplc_show_admin_write_page");
	add_submenu_page($wplc_plugin, __("Edit Events", $wplc_domain), __("Edit", $wplc_domain), "edit_posts", "wplc-edit", "wplc_show_admin_manage_page");
	// Import not ready for release
	//add_submenu_page($wplc_plugin, __("Import Events", $wplc_domain), __("Import", $wplc_domain), "import", "wplc-import", "wplc_show_import_page");
	add_submenu_page($wplc_plugin, __("Event Operations", $wplc_domain), __("Operations", $wplc_domain), "read", "wplc-ops", "wplc_show_admin_operations_page");
	add_options_page(__("WPListCal Settings", $wplc_domain), __("WPListCal", $wplc_domain), "manage_options", "wplc-options", "wplc_show_admin_options_page");
}

add_filter("favorite_actions", "wplc_favorite_actions_filter");
function wplc_favorite_actions_filter($actions) {
	global $wplc_plugin, $wplc_domain;
	wplc_setup();
	
	$actions['admin.php?page='.$wplc_plugin] = array(__("New Event", $wplc_domain), "edit_posts");
	return $actions;
}

add_action("right_now_table_end", "wplc_activity_box");
function wplc_activity_box() {
	global $wpdb;
	$tbl_name = get_option("wplc_tbl_name");
	$sql = "SELECT COUNT(*) FROM $tbl_name";
	$num = $wpdb->get_var($wpdb->escape($sql));
	$num = number_format_i18n($num);
	?>
	<tr>
		<td class="first b b-events"><a href="admin.php?page=wplc-edit"><?php echo $num; ?></a></td>
		<td class="t events"><?php echo __ngettext( 'Event', 'Events', $num ); ?></td>
		<td class="b">&nbsp;</td>
		<td class="t last">&nbsp;</td>
	</tr>
	<?php
}

add_filter("plugin_action_links_$wplc_plugin", 'wplc_actlinks' ); 
function wplc_actlinks($links) { 
	global $wplc_plugin;
	// Add a link to this plugin's settings page
	$settings_link = '<a href="options-general.php?page=wplc-options">Settings</a>'; 
	array_unshift( $links, $settings_link ); 
	return $links; 
}

add_action("wp_ajax_wplc_delete_event", "wplc_delete_event");
function wplc_delete_event($id=null) {
	wplc_setup();
	global $wplc_domain, $wpdb;
	
	if($id == null)
		$id = $wpdb->escape($_POST['id']);
		
	$tbl_name = $wpdb->escape(get_option("wplc_tbl_name"));
	
	$sql = "DELETE FROM ".$tbl_name." WHERE id=".$id;
	$wpdb->query($sql);
}

function wplc_show_admin_manage_page() {
	wplc_setup();
	global $wplc_domain, $wpdb, $wplc_plugin;
	
	wplc_upgrade_if_needed();
	
	if($_POST['action'] == "delete") {
		wplc_delete_event($_POST['id']);
		return;
	}
	
	if(($_GET['op'] == 'edit' || $_GET['op'] == 'editexport') && isset($_GET['id'])) {
		wplc_show_admin_edit_page($_GET['id'], $_GET['op'] == 'editexport');
		return;
	}
	
	if($_GET['op'] == 'delete') {
		if(function_exists('wp_nonce_url')) {
			check_admin_referer('wplc-delete-event');
		}
		
		wplc_delete_event($_GET['id']);
		
		// Set message
		$message = __("Event deleted", $wplc_domain);
	}
	
	// op == export on bottom of function

	$itemsperpage = get_option("wplc_manage_items_per_page");
	$page = $_GET['wplc_pg'];
	if(isset($page)) {
		$offset = $itemsperpage * ($page-1);
	}
	else {
		$offset = 0;
		$page = 1;
	}
	
	$use_24hr_time = get_option("wplc_use_24hr_time");
	if(!is_bool($use_24hr_time)) {
		$use_24hr_time = $use_24hr_time == "true";
	}
	
	// Check how many events there are
	$sql = "SELECT ID FROM ".$wpdb->escape(get_option("wplc_tbl_name"));
	$wpdb->query($sql);
	$totalevents = $wpdb->num_rows;
	

	// Get events for this page
	$sql = "SELECT id, event_name, event_loc, event_start_time, event_end_time, event_allday"
		 ." FROM ".$wpdb->escape(get_option("wplc_tbl_name"))
		 ." ORDER BY event_start_time DESC, event_end_time DESC"
		 ." LIMIT ".$wpdb->escape($offset).", ".$wpdb->escape($itemsperpage);
		$wpdb->show_errors();
	$events = $wpdb->get_results($sql, ARRAY_A);
	
	if($use_24hr_time)
		$dateformat = 'D, M j, Y @ G:i';
	else
		$dateformat = 'D, M j, Y @ g:ia';
	
	$allday_format = "D, M j";
	
	$delmsg = __("You are about to delete the event \'%s\'. \\n\'OK\' to delete, \'Cancel\' to stop.", $wplc_domain);
	
	if(!is_null($message)) {
	?>
		<div id="message" class="updated fade">
			<p>
				<?php echo $message; ?>
			</p>
		</div>
	<?php
	}
	?>
	
	<div class="wrap">
		<h2><?php _e("Edit Events", $wplc_domain); ?></h2>
		<div class="tablenav">
			<div class="tablenav-pages">
				<span class="displaying-num"><?php _e(sprintf("Displaying %d-%d of %d", $offset+1, $offset+count($events), $totalevents), $wplc_domain); ?></span>
				<?php
				if($offset + $itemsperpage < $totalevents) {
					echo "<a href='admin.php?wplc_pg=".($page+1)."&amp;page=wplc-edit' class='prev page-numbers'>";
					_e("&laquo; Previous Events", $wplc_domain);
					echo "</a>";
					$prevshown = true;
				}
				if($page > 1) {
					if($prevshown)
						echo " | ";
					echo "<a href='admin.php?wplc_pg=".($page-1)."&amp;page=wplc-edit' class='next page-numbers'>";
					_e("Next Events &raquo;", $wplc_domain);
					echo "</a>";
				}
				?>
			</div>
			<div class="alignleft">
				<a href="admin.php?page=<?php echo $wplc_plugin; ?>"><?php _e('Add New Event &raquo;', $wplc_domain); ?></a>
			</div>
		</div>
		<table class="widefat">
			<thead>
				<tr>
					<th scope="col" style="text-align:center;"><span class="hidden"><?php _e("ID", $wplc_domain); ?></span></th>
					<th scope="col"><?php _e("Event Name", $wplc_domain); ?></th>
					<th scope="col"><?php _e("Location", $wplc_domain); ?></th>
					<th scope="col"><?php _e("Start Date/Time", $wplc_domain); ?></th>
					<th scope="col"><?php _e("End Date/Time", $wplc_domain); ?></th>
				</tr>
			</thead>
			<tbody>

			<?php
			for($i=0; $i<count($events); $i++) {
				$class = $i % 2 == 0 ? " class='alternate'" : "";
				$useformat = $events[$i]['event_allday'] == 1 ? $allday_format : $dateformat;
				$start = date($useformat, $events[$i]['event_start_time']);
				$end = date($useformat, $events[$i]['event_end_time']);
			?>

				<tr id="event-<?php echo $events[$i]['id']; ?>" <?php echo $class; ?>>
					<th scope="row" style="text-align:center;" class="check-column"><?php echo $events[$i]['id']; ?></th>
					<td><a href="admin.php?id=<?php echo $events[$i]['id']; ?>&amp;page=wplc-edit&amp;op=edit" class="row-title"><?php echo stripslashes(stripslashes($events[$i]['event_name'])); ?></a>
						<div class="row-actions"><a href="admin.php?id=<?php echo $events[$i]['id']; ?>&amp;page=wplc-edit&amp;op=edit" class="edit"><?php _e("Edit", $wplc_domain); ?></a> | <a href="javascript:;" onclick="wplcDeleteEvent(<?php echo $events[$i]['id']; ?>, '<?php echo sprintf($delmsg, $events[$i]['event_name']); ?>');" class="submitdelete"><?php _e("Delete", $wplc_domain); ?></a> | <a href="admin.php?page=wplc-edit&amp;op=export&amp;id=<?php echo $events[$i]['id']; ?>"><?php _e("Export", $wplc_domain); ?></a></div>
					</td>
					<td><?php echo stripslashes(stripslashes($events[$i]['event_loc'])); ?></td>
					<td><?php echo $start; ?></td>
					<td><?php echo $end; ?></td>
				</tr>

			<?php
			}
			?>
	
			</tbody>
			<tfoot>
				<tr>
					<th scope="col" style="text-align:center;"><span class="hidden"><?php _e("ID", $wplc_domain); ?></span></th>
					<th scope="col"><?php _e("Event Name", $wplc_domain); ?></th>
					<th scope="col"><?php _e("Location", $wplc_domain); ?></th>
					<th scope="col"><?php _e("Start Date/Time", $wplc_domain); ?></th>
					<th scope="col"><?php _e("End Date/Time", $wplc_domain); ?></th>
				</tr>
			</tfoot>			
		</table>
		<div class="tablenav">
			<div class="tablenav-pages">
				<span class="displaying-num"><?php _e(sprintf("Displaying %d-%d of %d", $offset+1, $offset+count($events), $totalevents), $wplc_domain); ?></span>
				<?php
				if($offset + $itemsperpage < $totalevents) {
					echo "<a href='admin.php?wplc_pg=".($page+1)."&amp;page=wplc-edit' class='prev page-numbers'>";
					_e("&laquo; Previous Events", $wplc_domain);
					echo "</a>";
					$prevshown = true;
				}
				if($page > 1) {
					if($prevshown)
						echo " | ";
					echo "<a href='admin.php?wplc_pg=".($page-1)."&amp;page=wplc-edit' class='next page-numbers'>";
					_e("Next Events &raquo;", $wplc_domain);
					echo "</a>";
				}
				?>
			</div>
			<div class="alignleft" style="margin-top:6px;">
				<a href="admin.php?page=<?php echo $wplc_plugin; ?>"><?php _e('Add New Event &raquo;', $wplc_domain); ?></a>
			</div>
		</div>
		<br class="clear" />
	</div>
	<?php
	
	if($_GET['op'] == "export") {
		if(!empty($_GET['id'])) {
			wplc_export_events($_GET['id']);
		}
	}
}

function wplc_show_admin_edit_page($id, $export=false) {
	wplc_setup();
	global $wplc_domain, $wpdb;

	$action = $_POST['action'];
	if($action == "submitted") {
		wplc_process_event($_POST);
	}
	else {
		// Lookup event data for $id
		$sql = "SELECT e.*, u.display_name as event_author FROM ".$wpdb->escape(get_option("wplc_tbl_name"))." e LEFT JOIN  ".$wpdb->users." u ON e.event_author = u.ID WHERE e.id=".$wpdb->escape($id);
		$event = $wpdb->get_results($sql, ARRAY_A);

		// Show edit form
		wplc_show_event_form($event[0], null, $export);
	}
}

function wplc_show_import_page() {
	// Not ready for release
	return;
	
	wplc_setup();
	global $wplc_domain;
	
	$msgerr = false;	
	if(isset($_POST['submit'])) {
		if($_FILES['wplc_import_file']['type'] == "text/calendar") {
			$dir = get_option("wplc_upload_dir");

			if(empty($dir) || empty($url)) {
				wplc_init_upload_dir_settings();
				$dir = get_option("wplc_upload_dir");
			}
			
			$uploadfile = $dir.basename($_FILES['wplc_import_file']['name']);
			if(move_uploaded_file($_FILES['wplc_import_file']['tmp_name'], $uploadfile)) {
				if(wplc_import_events($uploadfile)) {
					$msgerr = true;
					$message = __("Events successfully imported", $wplc_domain);
					$class = "updated";
				}
				else {
					$msgerr = true;
					$message = __("Error: iCalendar file was not parsable", $wplc_domain);
					$class = "error";
				}
			}
			else {
				$msgerr = true;
				$message = __("Error: Upload failed", $wplc_domain);
				$class = "error";
			}
		}
		else {
			$msgerr = true;
			$message = __("Error: Invalid file type uploaded. Please upload an iCalendar file. Type: ".$_FILES['wplc_import_file']['type'], $wplc_domain);
			$class = "error";
		}
	}
	
	if($msgerr) {
	?>
	<div id="message" class="<?php echo $class; ?>">
		<p>
			<?php echo $message; ?>
		</p>
	</div>
	<?php	
	}
	
	?>
	<div class="wrap">
		<h2><?php _e("Import Events", $wplc_domain); ?></h2>
		<p>
			<?php _e("WPListCal can import events from iCalendar files saved from programs like Apple iCal, Microsoft Outlook, and Mozilla Sunbird. Choose an iCalendar (.ics) file using the selector below and press &quot;Import&quot; to add all the events in the file to your WPListCal calendar.", $wplc_domain); ?>
		</p>
		<p>
			<?php _e("Events will maintain the creation timestamp from the file, but the author will be listed as the account you are currently logged in as. The modified time will be changed to the current time.", $wplc_domain); ?>
		</p>
		<form method="post" action="admin.php?page=wplc-import" enctype="multipart/form-data">
			<p>
				<label for="wplc_import_file"><?php _e("iCalendar File:", $wplc_domain); ?></label>
				<input type="file" name="wplc_import_file" id="wplc_import_file" />
			</p>
			<p>
				<input type="submit" class="button-primary" name="submit" value="<?php _e('Import', $wplc_domain); ?>" />
			</p>
		</form>
	<?php
}

function wplc_show_admin_operations_page() {
	wplc_setup();
	global $wplc_domain;
	
	$can_cleanup = current_user_can("delete_posts");
	
	if($_GET['op'] == "cleanup" && $can_cleanup) {
		$num = wplc_cleanup_events();
		if($num > 0) {
			$message = sprintf(__("%d old ".($num == 1 ? "event" : "events")." deleted.", $wplc_domain), $num);
			$class = "updated";
		}
		elseif($num == 0) {
			$message = __("No old events to delete.", $wplc_domain);
			$class = "updated";
		}
		else {
			$message = __("Error: Event cleanup failed.", $wplc_domain);
			$class = "error";
		}
		?>
		<div id="message" class="<?php echo $class; ?>">
			<p>
				<?php echo $message; ?>
			</p>
		</div>
		<?php
	}
	?>
	<div class="wrap">
		<h2><?php _e("Export Events", $wplc_domain); ?></h2>
		<p>
			<?php printf(__("WPListCal can save your events in the standard iCalendar format. Events are stored in the timezone that your blog is set to use. All events are exported at once, past and future. If you'd like to export a single event, go to the %smanage events%s page and click &quot;Export&quot; near the event you want to export.", $wplc_domain), "<a href='admin.php?page=wplc-edit'>", "</a>"); ?>
		</p>
		<h3><a href="admin.php?page=wplc-ops&amp;op=export"><?php _e("Export events &raquo;", $wplc_domain); ?></a></h3>
		
		<?php
		if($can_cleanup) :
		?>
			<h2><?php _e("Cleanup Events", $wplc_domain); ?></h2>
			<p>
				<?php _e("Have a bunch of old events sitting around? Click below to delete all events that have ended already. Note that this operation CANNOT be undone.", $wplc_domain); ?>
			</p>
			<h3><a href="admin.php?page=wplc-cleanup&amp;op=cleanup" onclick="return confirm('<?php _e("Are you sure you want to delete all past events?", $wplc_domain); ?>');"><?php _e("Cleanup events &raquo;", $wplc_domain); ?></a></h3>
		<?php
		endif;
		?>
	</div>
	<?php
	
	if($_GET['op'] == "export") {
		wplc_export_events();
	}
}

function wplc_cleanup_events() {
	global $wpdb;
	
	$sql = "DELETE FROM ".$wpdb->escape(get_option("wplc_tbl_name"))." WHERE event_end_time < ".wplc_time();
	$result = $wpdb->query($sql);
	
	if($result === false)
		return -1;
	return $result;
}

function wplc_show_admin_options_page() {
	wplc_setup();
	global $wplc_domain;
	
	$use_24hr_time = get_option("wplc_use_24hr_time");
	if(!is_bool($use_24hr_time)) {
		$use_24hr_time = $use_24hr_time == "true";
	}
	
	$open_links_in_new_window = get_option("wplc_open_links_in_new_window");
	if(!is_bool($open_links_in_new_window)) {
		$open_links_in_new_window = $open_links_in_new_window == "true";
	}
	
	$hide_same_date = get_option("wplc_hide_same_date");
	if(!is_bool($hide_same_date)) {
		$hide_same_date = $hide_same_date == "true";
	}
	
	$nofollow_links = get_option("wplc_nofollow_links");
	if(!is_bool($nofollow_links)) {
		$nofollow_links = $nofollow_links == "true";
	}
	?>
	
	<div class="wrap">
		<form method="post" action="options.php">
			<?php wp_nonce_field('update-options'); ?>
			<h2><?php _e("WPListCal Options", $wplc_domain); ?></h2>
			<table class="form-table">
				<tr valign="top" id="displaymode">
					<th scope="row"><?php _e("Display Mode:", $wplc_domain); ?></th>
					<td>
						<input type="radio" name="wplc_display_mode" value="list" id="wplc_display_mode_list" onclick="wplc_changeDisabled('wplc_event_format', false);"<?php echo get_option('wplc_display_mode') == 'list' ? "checked='checked'" : ""; ?> />
							<label for="wplc_display_mode_list"><?php _e("Show events in an unordered list <em>(Default)</em>", $wplc_domain); ?></label>
						<br />
						<fieldset style="margin-left: 25px;border:none;">
							<legend style="float:left; margin-top:2px;"><?php _e("Event Format", $wplc_domain); ?> <a href="javascript:;" title="<?php _e("The following variables are available:", $wplc_domain); ?> %NAME%, %LINK%, %LINKEDNAME%, %LOCATION%, %DESCRIPTION%, %START%, %END%, and %AUTHOR%.
								
Put words into curly brackets to make them dependent on the first variable in the bracketed statement. Use '^' to escape brackets or to stop a variable from being the dependent variable for a statement." style="cursor:help;">?</a>:</legend>
							<div>
								<textarea name="wplc_event_format" id="wplc_event_format" style="width:350px; height:50px;" class="large-text code"<?php echo get_option('wplc_display_mode') == 'list' ? "" : "disabled='disabled'"; ?>><?php echo htmlentities(get_option('wplc_event_format')); ?></textarea>
							</div>
						</fieldset>
						<input type="radio" name="wplc_display_mode" value="table" id="wplc_display_mode_table" onclick="wplc_changeDisabled('wplc_event_format', true);"<?php echo get_option('wplc_display_mode') == 'table' ? "checked='checked'" : ""; ?> />
							<label for="wplc_display_mode_table"><?php _e("Show events in a table", $wplc_domain); ?></label>
					</td>
				</tr>
				<tr valign="top" id="dateformat">
					<th scope="row"><?php _e("Date/Time Format:", $wplc_domain); ?></th>
					<td>
						<input type="text" name="wplc_date_format" value="<?php echo get_option('wplc_date_format'); ?>" class="regular-text" />
						<span class="setting-description"><a href="http://codex.wordpress.org/Formatting_Date_and_Time"><?php _e("Documentation on date formatting", $wplc_domain); ?></a>. <?php _e("Click &quot;Save Changes&quot; to update sample output.", $wplc_domain); ?></span>
						<br />
						<strong><?php _e("Output:", $wplc_domain); ?></strong> <?php echo date(get_option('wplc_date_format'), wplc_time()); ?>
					</td>
				</tr>
				<tr valign="top" id="24hr_time">
					<th scope="row"><?php _e("12/24 Hour Time:", $wplc_domain); ?></th>
					<td>
						<input type="radio" name="wplc_use_24hr_time" id="wplc_use_24hr_time0" value="false"<?php echo $use_24hr_time ? '' : ' checked=\'checked\''; ?> />
						<label for="wplc_use_24hr_time0"><?php _e("Use 12 hour time (e.g. 1:35pm)", $wplc_domain); ?></label>
						<br />
						<input type="radio" name="wplc_use_24hr_time" id="wplc_use_24hr_time1" value="true"<?php echo $use_24hr_time ? ' checked=\'checked\'' : ''; ?> />
						<label for="wplc_use_24hr_time1"><?php _e("Use 24 hour time (e.g. 13:35)", $wplc_domain); ?></label>
						<br />
						<span class="setting-description"><?php _e("What time-style to use in the admin area (does not affect what is displayed on your site)", $wplc_domain); ?></span>
					</td>
				</tr>
				<tr valign="top" id="hide_same_date">
					<th scope="row"><?php _e("End Date Options:", $wplc_domain); ?></th>
					<td>
						<input type="radio" name="wplc_hide_same_date" value="true" id="wplc_hide_same_date_true" onclick="wplc_changeDisabled('wplc_date2_time_format', false);"<?php echo $hide_same_date ? "checked='checked'" : ""; ?> />
							<label for="wplc_hide_same_date_true"><?php _e("If event starts and ends on the same day, use the time format below for the end date <em>(Default)</em>", $wplc_domain); ?></label>
						<br />
						<fieldset style="margin-left: 25px;border:none;">
							<legend style="float:left; margin-top:2px;"><?php _e("End Date Format", $wplc_domain); ?>:</legend>
							<div>
								<input type="text" name="wplc_date2_time_format" id="wplc_date2_time_format" value="<?php echo get_option('wplc_date2_time_format'); ?>"<?php echo $hide_same_date ? "" : "disabled='disabled'"; ?> class="small-text" />
								<strong><?php _e("Output:", $wplc_domain); ?></strong> <?php echo date(get_option('wplc_date2_time_format'), wplc_time()); ?>
							</div>
						</fieldset>
						<input type="radio" name="wplc_hide_same_date" value="false" id="wplc_hide_same_date_false" onclick="wplc_changeDisabled('wplc_date2_time_format', true);"<?php echo $hide_same_date ? "" : "checked='checked'"; ?> />
							<label for="wplc_hide_same_date_false"><?php _e("Use the same format for both start and end dates", $wplc_domain); ?></label>
					</td>
				</tr>
				<tr valign="top" id="maxevents">
					<th scope="row"><?php _e("Maximum Displayed Events:", $wplc_domain); ?></th>
					<td>
						<input type="text" name="wplc_max_events" size="4" value="<?php echo get_option('wplc_max_events'); ?>" class="small-text" />
						<span class="setting-description"><?php _e("How many events to display in the event list, -1 for no limit", $wplc_domain); ?></span>
					</td>
				</tr>
				<tr valign="top" id="advancenotice">
					<th scope="row"><?php _e("Maximum Advanced Notice:", $wplc_domain); ?></th>
					<td>
						<input type="text" name="wplc_advance_days" size="4" value="<?php echo get_option('wplc_advance_days'); ?>" class="small-text" />
						<span class="setting-description"><?php _e("How many days in advance to display events, -1 for no limit", $wplc_domain); ?></span>
					</td>
				</tr>
				<tr valign="top" id="showpastevents">
					<th scope="row"><?php _e("Past Events:", $wplc_domain); ?></th>
					<td>
						<input type="radio" name="wplc_show_past_events" value="false" id="wplc_show_past_events_false"<?php echo get_option('wplc_show_past_events') != 'true' ? "checked='checked'" : ""; ?> />
							<label for="wplc_show_past_events_false"><?php _e("Only show current and future events", $wplc_domain); ?></label>
						<br />
						<input type="radio" name="wplc_show_past_events" value="true" id="wplc_show_past_events_true"<?php echo get_option('wplc_show_past_events') == 'true' ? "checked='checked'" : ""; ?> />
							<label for="wplc_show_past_events_true"><?php _e("Show all events, even if they have already occurred", $wplc_domain); ?></label>
					</td>
				</tr>
				<tr valign="top" id="eventorder">
					<th scope="row"><?php _e("Event Order:", $wplc_domain); ?></th>
					<td>
						<input type="radio" name="wplc_event_order" value="asc" id="wplc_event_order_asc"<?php echo get_option('wplc_event_order') == 'asc' ? "checked='checked'" : ""; ?> />
							<label for="wplc_event_order_asc"><?php _e("Show the closest event first", $wplc_domain); ?></label>
						<br />
						<input type="radio" name="wplc_event_order" value="desc" id="wplc_event_order_desc"<?php echo get_option('wplc_event_order') == 'desc' ? "checked='checked'" : ""; ?> />
							<label for="wplc_event_order_desc"><?php _e("Show the furthest event first", $wplc_domain); ?></label>
					</td>
				</tr>
				<tr valign="top" id="no_events_msg">
					<th scope="row"><?php _e("No Events Message:", $wplc_domain); ?></th>
					<td>
						<input type="text" name="wplc_no_events_msg" size="30" value="<?php echo get_option('wplc_no_events_msg'); ?>" class="regular-text" />
						<span class="setting-description"><?php _e("Message to show if there are no events, leave blank for none", $wplc_domain); ?></span>
					</td>
				</tr>
				<tr valign="top" id="adminperpage">
					<th scope="row"><?php _e("Admin Items Per Page:", $wplc_domain); ?></th>
					<td>
						<input type="text" name="wplc_manage_items_per_page" size="4" value="<?php echo get_option('wplc_manage_items_per_page'); ?>" class="small-text" />
						<span class="setting-description"><?php _e("How many events to display per page on the Manage Events admin page", $wplc_domain); ?></span>
					</td>
				</tr>
				<tr valign="top" id="open_links_in_new_window">
					<th scope="row"><?php _e("Event Link Target:", $wplc_domain); ?></th>
					<td>
						<input type="radio" name="wplc_open_links_in_new_window" id="wplc_open_links_in_new_window0" value="false"<?php echo $open_links_in_new_window ? '' : ' checked=\'checked\''; ?> />
						<label for="wplc_open_links_in_new_window0"><?php _e("Open links in the current window", $wplc_domain); ?></label>
						<br />
						<input type="radio" name="wplc_open_links_in_new_window" id="wplc_open_links_in_new_window1" value="true"<?php echo $open_links_in_new_window ? ' checked=\'checked\'' : ''; ?> />
						<label for="wplc_open_links_in_new_window1"><?php _e("Open links in a new window", $wplc_domain); ?></label>
					</td>
				</tr>
				<tr valign="top" id="nofollow_links">
					<th scope="row"><?php _e("Link No Follow:", $wplc_domain); ?></th>
					<td>
						<input type="checkbox" name="wplc_nofollow_links" id="wplc_nofollow_links" value="true"<?php echo $nofollow_links ? ' checked=\'checked\'' : ''; ?> />
						<label for="wplc_nofollow_links"><?php _e("Set rel=&quot;nofollow&quot; on links", $wplc_domain); ?></label>
					</td>
				</tr>
			</table>
			<input type="hidden" name="action" value="update" />
			<input type="hidden" name="page_options" value="wplc_display_mode,wplc_event_format,wplc_date_format,wplc_use_24hr_time,wplc_hide_same_date,wplc_date2_time_format,wplc_max_events,wplc_advance_days,wplc_show_past_events,wplc_no_events_msg,wplc_manage_items_per_page,wplc_open_links_in_new_window,wplc_nofollow_links" />
			<p class="submit"><input type="submit" name="Submit" value="<?php _e("Save Changes", $wplc_domain); ?>" class="button-primary" /></p>
		</form>
	</div>
	
	<?php
}

function wplc_widget_init() {
	if (!function_exists('register_sidebar_widget') || !function_exists('register_widget_control'))
		return;
		
	function wplc_widget($args) {
		extract($args);
		
		$widget_title = get_option("wplc_widget_title");
		
		echo $before_widget;
		echo $before_title . $widget_title . $after_title;
		echo wplc_show_events();
		echo $after_widget;
	}
	
	function wplc_widget_control() {
		global $wplc_domain;
		wplc_setup();
		
		$wplc_widget_title = get_option("wplc_widget_title");
		
		if($_POST['wplc_submit'] == "1") {
			$wplc_widget_new_title = strip_tags(stripslashes($_POST['wplc_widget_title']));
			if($wplc_widget_title != $wplc_widget_new_title) {
				$wplc_widget_title = $wplc_widget_new_title;
				update_option("wplc_widget_title", $wplc_widget_title);
			}
		}
		
		$wplc_widget_title = htmlspecialchars($wplc_widget_title, ENT_QUOTES);
		
		?>
		<div>
			<label for="wplc_widget_title"><?php _e("Widget Title:", $wplc_domain); ?></label><input type="text" id="wplc_widget_title" name="wplc_widget_title" value="<?php echo $wplc_widget_title; ?>" />
			<input type="hidden" name="wplc_submit" id="wplc_submit" value="1" />
		</div>
		<?php
	}
	
	register_sidebar_widget("WPListCal", "wplc_widget");
	register_widget_control("WPListCal", "wplc_widget_control");
}

add_action("plugins_loaded", "wplc_widget_init");
?>